from django.urls import include, path, re_path
from pretalx.event.models.event import SLUG_REGEX

from .views import (
    AssigneeView,
    EnhancedSubmissionList,
    ExportView,
    JoinView,
    MayAdvanceView,
    MusicrateSettingsView,
    PresenterView,
    QRCodeView,
    RatingView,
    ScoreExportView,
)

urlpatterns = [
    re_path(
        rf"^orga/event/(?P<event>{SLUG_REGEX})/",
        include(
            [
                path(
                    "settings/p/pretalx_musicrate/",
                    MusicrateSettingsView.as_view(),
                    name="settings.musicrate",
                ),
                path(
                    "p/pretalx_musicrate/",
                    include(
                        [
                            path("export/", ExportView.as_view(), name="export"),
                            path(
                                "list/",
                                EnhancedSubmissionList.as_view(),
                                name="enhanced_list",
                            ),
                            path("scores/", ScoreExportView.as_view(), name="scores"),
                            path("<code>/", AssigneeView.as_view(), name="assignee"),
                        ]
                    ),
                ),
            ]
        ),
    ),
    re_path(
        rf"^(?P<event>{SLUG_REGEX})/p/pretalx_musicrate/",
        include(
            [
                path("", QRCodeView.as_view(), name="qrcode"),
                path("present/<code>/", PresenterView.as_view(), name="present"),
                path(
                    "present/<code>/may-advance",
                    MayAdvanceView.as_view(),
                    name="may_advance",
                ),
                path("<slug:token>/", JoinView.as_view(), name="join"),
                path("<slug:token>/<code>/", RatingView.as_view(), name="rating"),
            ]
        ),
    ),
]
